summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorAndroid Build Coastguard Worker <android-build-coastguard-worker@google.com>2022-04-08 16:02:58 +0000
committerAndroid Build Coastguard Worker <android-build-coastguard-worker@google.com>2022-04-08 16:02:58 +0000
commit57bd7556fa827873311ad11ed7d59f9522825dcb (patch)
treef513fe6d803e7f8f4ec8e70ae4563115b48cede7
parentf4ef9f38f9bf38e6365b7d1619f2f6f13ca392cd (diff)
parentd1ed658e4bd2e6e4d32fb9ebea9bcf8bfb48d78b (diff)
downloadCalendar-android12-mainline-tzdata2-release.tar.gz
Change-Id: I1b45670c952507bdd45ce53190556bd815aa9281
-rw-r--r--Android.mk3
-rw-r--r--AndroidManifest.xml18
-rw-r--r--MODULE_LICENSE_APACHE20
-rw-r--r--res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml2
-rw-r--r--src/com/android/calendar/EventInfoFragment.java4
-rw-r--r--src/com/android/calendar/StickyHeaderListView.java18
-rw-r--r--src/com/android/calendar/widget/CalendarAppWidgetService.java3
-rw-r--r--tests/Android.mk3
8 files changed, 18 insertions, 33 deletions
diff --git a/Android.mk b/Android.mk
index dce26a46..82d5d54a 100644
--- a/Android.mk
+++ b/Android.mk
@@ -34,9 +34,6 @@ LOCAL_SDK_VERSION := current
LOCAL_RESOURCE_DIR := $(addprefix $(LOCAL_PATH)/, $(res_dirs))
LOCAL_PACKAGE_NAME := Calendar
-LOCAL_LICENSE_KINDS := SPDX-license-identifier-Apache-2.0
-LOCAL_LICENSE_CONDITIONS := notice
-LOCAL_NOTICE_FILE := $(LOCAL_PATH)/NOTICE
LOCAL_PROGUARD_FLAG_FILES := proguard.flags
diff --git a/AndroidManifest.xml b/AndroidManifest.xml
index c9c5a04b..1e78c72e 100644
--- a/AndroidManifest.xml
+++ b/AndroidManifest.xml
@@ -80,8 +80,7 @@
<activity android:name="EventInfoActivity"
android:parentActivityName="com.android.calendar.AllInOneActivity"
- android:theme="@style/CalendarTheme.WithActionBar"
- android:exported="true">
+ android:theme="@style/CalendarTheme.WithActionBar">
<intent-filter>
<action android:name="android.intent.action.VIEW" />
<category android:name="android.intent.category.DEFAULT" />
@@ -118,8 +117,7 @@
<activity android:name="GoogleCalendarUriIntentFilter" android:label="@string/app_label"
android:theme="@android:style/Theme.NoDisplay"
- android:configChanges="orientation|keyboardHidden"
- android:exported="true">
+ android:configChanges="orientation|keyboardHidden">
<intent-filter
android:priority="50">
@@ -140,8 +138,7 @@
android:theme="@android:style/Theme.Holo.Dialog" android:excludeFromRecents="true"
android:label="@string/quick_response_dialog_title" />
- <receiver android:name=".alerts.AlertReceiver"
- android:exported="true">
+ <receiver android:name=".alerts.AlertReceiver">
<intent-filter>
<action android:name="android.intent.action.EVENT_REMINDER" />
<action android:name="android.intent.action.TIME_SET" />
@@ -163,8 +160,7 @@
<receiver android:name=".alerts.GlobalDismissManager"
android:exported="false" />
- <receiver android:name=".UpgradeReceiver"
- android:exported="true">
+ <receiver android:name=".UpgradeReceiver">
<intent-filter>
<action android:name="android.intent.action.BOOT_COMPLETED" />
<category android:name="android.intent.category.DEFAULT" />
@@ -184,8 +180,7 @@
<service android:name=".alerts.InitAlarmsService" />
<!-- Declarations for the widget -->
- <receiver android:name=".widget.CalendarAppWidgetProvider" android:label="@string/gadget_title"
- android:exported="true">
+ <receiver android:name=".widget.CalendarAppWidgetProvider" android:label="@string/gadget_title">
<intent-filter>
<action android:name="android.appwidget.action.APPWIDGET_UPDATE" />
<action android:name="com.android.calendar.APPWIDGET_UPDATE" />
@@ -193,8 +188,7 @@
<meta-data android:name="android.appwidget.provider" android:resource="@xml/appwidget_info" />
</receiver>
- <receiver android:name=".widget.CalendarAppWidgetService$CalendarFactory"
- android:exported="true">
+ <receiver android:name=".widget.CalendarAppWidgetService$CalendarFactory">
<intent-filter>
<action android:name="android.intent.action.TIMEZONE_CHANGED"/>
<action android:name="android.intent.action.DATE_CHANGED"/>
diff --git a/MODULE_LICENSE_APACHE2 b/MODULE_LICENSE_APACHE2
new file mode 100644
index 00000000..e69de29b
--- /dev/null
+++ b/MODULE_LICENSE_APACHE2
diff --git a/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml b/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
index 5e315825..7f64a7b2 100644
--- a/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
+++ b/res/layout-sw600dp-w960dp-h527dp-land/all_in_one.xml
@@ -55,7 +55,7 @@
android:textSize="18sp" />
</LinearLayout>
- <!-- This is a nonessential view to make hiding/unhiding easier -->
+ <!-- This is a dummy view to make hiding/unhiding easier -->
<View
android:id="@+id/mini_month_container"
android:layout_below="@id/date_group"
diff --git a/src/com/android/calendar/EventInfoFragment.java b/src/com/android/calendar/EventInfoFragment.java
index 0aa83d02..b95c7c3d 100644
--- a/src/com/android/calendar/EventInfoFragment.java
+++ b/src/com/android/calendar/EventInfoFragment.java
@@ -217,8 +217,8 @@ public class EventInfoFragment extends DialogFragment implements OnCheckedChange
static {
if (!Utils.isJellybeanOrLater()) {
- EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_PACKAGE] = Events._ID; // nonessential value
- EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_URI] = Events._ID; // nonessential value
+ EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_PACKAGE] = Events._ID; // dummy value
+ EVENT_PROJECTION[EVENT_INDEX_CUSTOM_APP_URI] = Events._ID; // dummy value
}
}
diff --git a/src/com/android/calendar/widget/CalendarAppWidgetService.java b/src/com/android/calendar/widget/CalendarAppWidgetService.java
index ec702c7c..6329463b 100644
--- a/src/com/android/calendar/widget/CalendarAppWidgetService.java
+++ b/src/com/android/calendar/widget/CalendarAppWidgetService.java
@@ -542,9 +542,6 @@ public class CalendarAppWidgetService extends RemoteViewsService {
}
AppWidgetManager widgetManager = AppWidgetManager.getInstance(mContext);
- if (widgetManager == null) {
- return;
- }
if (mAppWidgetId == -1) {
int[] ids = widgetManager.getAppWidgetIds(CalendarAppWidgetProvider
.getComponentName(mContext));
diff --git a/tests/Android.mk b/tests/Android.mk
index 2d74b1ee..bacb8c04 100644
--- a/tests/Android.mk
+++ b/tests/Android.mk
@@ -12,9 +12,6 @@ LOCAL_STATIC_JAVA_LIBRARIES := android.test.runner
LOCAL_SRC_FILES := $(call all-java-files-under, src)
LOCAL_PACKAGE_NAME := CalendarTests
-LOCAL_LICENSE_KINDS := SPDX-license-identifier-Apache-2.0
-LOCAL_LICENSE_CONDITIONS := notice
-LOCAL_NOTICE_FILE := $(LOCAL_PATH)/../NOTICE
LOCAL_INSTRUMENTATION_FOR := Calendar
diff --git a/src/com/android/calendar/StickyHeaderListView.java b/src/com/android/calendar/StickyHeaderListView.java
index 981e7af7..25955a05 100644
--- a/src/com/android/calendar/StickyHeaderListView.java
+++ b/src/com/android/calendar/StickyHeaderListView.java
@@ -58,7 +58,7 @@ public class StickyHeaderListView extends FrameLayout implements OnScrollListene
protected HeaderIndexer mIndexer = null;
protected HeaderHeightListener mHeaderHeightListener = null;
protected View mStickyHeader = null;
- protected View mNonessentialHeader = null; // A invisible header used when a section has no header
+ protected View mDummyHeader = null; // A invisible header used when a section has no header
protected ListView mListView = null;
protected ListView.OnScrollListener mListener = null;
@@ -269,11 +269,11 @@ public class StickyHeaderListView extends FrameLayout implements OnScrollListene
boolean newView = false;
if (sectionPos != mCurrentSectionPos) {
// No header for current position , use the nonessential invisible one, hide the separator
if (sectionPos == -1) {
sectionSize = 0;
this.removeView(mStickyHeader);
- mStickyHeader = mNonessentialHeader;
+ mStickyHeader = mDummyHeader;
if (mSeparatorView != null) {
mSeparatorView.setVisibility(View.GONE);
}
@@ -320,14 +320,14 @@ public class StickyHeaderListView extends FrameLayout implements OnScrollListene
}
} else if (stickyHeaderHeight != 0) {
mStickyHeader.setTranslationY(0);
- if (mSeparatorView != null && !mStickyHeader.equals(mNonessentialHeader)) {
+ if (mSeparatorView != null && !mStickyHeader.equals(mDummyHeader)) {
mSeparatorView.setVisibility(View.VISIBLE);
}
}
if (newView) {
mStickyHeader.setVisibility(View.INVISIBLE);
this.addView(mStickyHeader);
- if (mSeparatorView != null && !mStickyHeader.equals(mNonessentialHeader)){
+ if (mSeparatorView != null && !mStickyHeader.equals(mDummyHeader)){
FrameLayout.LayoutParams params =
new FrameLayout.LayoutParams(LayoutParams.MATCH_PARENT,
mSeparatorWidth);
@@ -382,12 +382,12 @@ public class StickyHeaderListView extends FrameLayout implements OnScrollListene
setListView(new ListView(mContext));
}
- // Create a nonessential view , it will be used in case a section has no header
- mNonessentialHeader = new View (mContext);
+ // Create a dummy view , it will be used in case a section has no header
+ mDummyHeader = new View (mContext);
ViewGroup.LayoutParams params = new LayoutParams(LayoutParams.MATCH_PARENT,
1, Gravity.TOP);
- mNonessentialHeader.setLayoutParams(params);
- mNonessentialHeader.setBackgroundColor(Color.TRANSPARENT);
+ mDummyHeader.setLayoutParams(params);
+ mDummyHeader.setBackgroundColor(Color.TRANSPARENT);
mChildViewsCreated = true;
}
@@ -269,11 +269,11 @@ public class StickyHeaderListView extends FrameLayout implements OnScrollListene
boolean newView = false;
if (sectionPos != mCurrentSectionPos) {
- // No header for current position , use the nonessential invisible one, hide the separator
+ // No header for current position , use the dummy invisible one, hide the separator
if (sectionPos == -1) {
sectionSize = 0;